==> commons-io-2.11.0-src.tar.gz: commons-io-2.11.0-src/src/test/java/org/apache/commons/io/output/NullPrintStreamTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.io.output;


import java.io.IOException;

import org.junit.jupiter.api.Test;


/**
 * Really not a lot to do here, but checking that no Exceptions are thrown.
 */
public class NullPrintStreamTest {

    private void process(final NullPrintStream nos) throws IOException {
        nos.write("string".getBytes());
        nos.write("some string".getBytes(), 3, 5);
        nos.write(1);
        nos.write(0x0f);
        nos.flush();
        nos.close();
        nos.write("allowed".getBytes());
        nos.write(255);
    }

    @Test
    public void testNullNewInstance() throws IOException {
        try (final NullPrintStream nos = new NullPrintStream()) {
            process(nos);
        }
    }

    @Test
    public void testNullSingleton() throws IOException {
        try (final NullPrintStream nos = NullPrintStream.NULL_PRINT_STREAM) {
            process(nos);
        }
    }

}

==> commons-io-2.12.0-src.tar.gz: commons-io-2.12.0-src/src/test/java/org/apache/commons/io/output/NullPrintStreamTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.io.output;


import java.io.IOException;

import org.junit.jupiter.api.Test;


/**
 * Really not a lot to do here, but checking that no Exceptions are thrown.
 */
public class NullPrintStreamTest {

    private void process(final NullPrintStream nos) throws IOException {
        nos.write("string".getBytes());
        nos.write("some string".getBytes(), 3, 5);
        nos.write(1);
        nos.write(0x0f);
        nos.flush();
        nos.close();
        nos.write("allowed".getBytes());
        nos.write(255);
    }

    @Test
    public void testNullNewInstance() throws IOException {
        try (NullPrintStream nos = new NullPrintStream()) {
            process(nos);
        }
    }

    @Test
    public void testNullSingleton() throws IOException {
        try (NullPrintStream nos = NullPrintStream.INSTANCE) {
            process(nos);
        }
    }

}
